from enum import Enum


class CountryCode(str, Enum):
    """An enumeration of all ISO-3166 alpha-2 country codes."""  # noqa: E501

    """# Afghanistan """  # noqa: E501
    AF = "AF"
    """# Åland Islands """  # noqa: E501
    AX = "AX"
    """# Albania """  # noqa: E501
    AL = "AL"
    """# Algeria """  # noqa: E501
    DZ = "DZ"
    """# American Samoa """  # noqa: E501
    AS = "AS"
    """# Andorra """  # noqa: E501
    AD = "AD"
    """# Angola """  # noqa: E501
    AO = "AO"
    """# Anguilla """  # noqa: E501
    AI = "AI"
    """# Antarctica """  # noqa: E501
    AQ = "AQ"
    """# Antigua and Barbuda """  # noqa: E501
    AG = "AG"
    """# Argentina """  # noqa: E501
    AR = "AR"
    """# Armenia """  # noqa: E501
    AM = "AM"
    """# Aruba """  # noqa: E501
    AW = "AW"
    """# Australia """  # noqa: E501
    AU = "AU"
    """# Austria """  # noqa: E501
    AT = "AT"
    """# Azerbaijan """  # noqa: E501
    AZ = "AZ"
    """# Bahamas """  # noqa: E501
    BS = "BS"
    """# Bahrain """  # noqa: E501
    BH = "BH"
    """# Bangladesh """  # noqa: E501
    BD = "BD"
    """# Barbados """  # noqa: E501
    BB = "BB"
    """# Belarus """  # noqa: E501
    BY = "BY"
    """# Belgium """  # noqa: E501
    BE = "BE"
    """# Belize """  # noqa: E501
    BZ = "BZ"
    """# Benin """  # noqa: E501
    BJ = "BJ"
    """# Bermuda """  # noqa: E501
    BM = "BM"
    """# Bhutan """  # noqa: E501
    BT = "BT"
    """# Bolivia (Plurinational State of) """  # noqa: E501
    BO = "BO"
    """# Bonaire, Sint Eustatius and Saba """  # noqa: E501
    BQ = "BQ"
    """# Bosnia and Herzegovina """  # noqa: E501
    BA = "BA"
    """# Botswana """  # noqa: E501
    BW = "BW"
    """# Bouvet Island """  # noqa: E501
    BV = "BV"
    """# Brazil """  # noqa: E501
    BR = "BR"
    """# British Indian Ocean Territory """  # noqa: E501
    IO = "IO"
    """# Brunei Darussalam """  # noqa: E501
    BN = "BN"
    """# Bulgaria """  # noqa: E501
    BG = "BG"
    """# Burkina Faso """  # noqa: E501
    BF = "BF"
    """# Burundi """  # noqa: E501
    BI = "BI"
    """# Cabo Verde """  # noqa: E501
    CV = "CV"
    """# Cambodia """  # noqa: E501
    KH = "KH"
    """# Cameroon """  # noqa: E501
    CM = "CM"
    """# Canada """  # noqa: E501
    CA = "CA"
    """# Cayman Islands """  # noqa: E501
    KY = "KY"
    """# Central African Republic """  # noqa: E501
    CF = "CF"
    """# Chad """  # noqa: E501
    TD = "TD"
    """# Chile """  # noqa: E501
    CL = "CL"
    """# China """  # noqa: E501
    CN = "CN"
    """# Christmas Island """  # noqa: E501
    CX = "CX"
    """# Cocos (Keeling) Islands """  # noqa: E501
    CC = "CC"
    """# Colombia """  # noqa: E501
    CO = "CO"
    """# Comoros """  # noqa: E501
    KM = "KM"
    """# Congo """  # noqa: E501
    CG = "CG"
    """# Congo (Democratic Republic of the) """  # noqa: E501
    CD = "CD"
    """# Cook Islands """  # noqa: E501
    CK = "CK"
    """# Costa Rica """  # noqa: E501
    CR = "CR"
    """# Côte d'Ivoire """  # noqa: E501
    CI = "CI"
    """# Croatia """  # noqa: E501
    HR = "HR"
    """# Cuba """  # noqa: E501
    CU = "CU"
    """# Curaçao """  # noqa: E501
    CW = "CW"
    """# Cyprus """  # noqa: E501
    CY = "CY"
    """# Czechia """  # noqa: E501
    CZ = "CZ"
    """# Denmark """  # noqa: E501
    DK = "DK"
    """# Djibouti """  # noqa: E501
    DJ = "DJ"
    """# Dominica """  # noqa: E501
    DM = "DM"
    """# Dominican Republic """  # noqa: E501
    DO = "DO"
    """# Ecuador """  # noqa: E501
    EC = "EC"
    """# Egypt """  # noqa: E501
    EG = "EG"
    """# El Salvador """  # noqa: E501
    SV = "SV"
    """# Equatorial Guinea """  # noqa: E501
    GQ = "GQ"
    """# Eritrea """  # noqa: E501
    ER = "ER"
    """# Estonia """  # noqa: E501
    EE = "EE"
    """# Ethiopia """  # noqa: E501
    ET = "ET"
    """# Falkland Islands (Malvinas) """  # noqa: E501
    FK = "FK"
    """# Faroe Islands """  # noqa: E501
    FO = "FO"
    """# Fiji """  # noqa: E501
    FJ = "FJ"
    """# Finland """  # noqa: E501
    FI = "FI"
    """# France """  # noqa: E501
    FR = "FR"
    """# French Guiana """  # noqa: E501
    GF = "GF"
    """# French Polynesia """  # noqa: E501
    PF = "PF"
    """# French Southern Territories """  # noqa: E501
    TF = "TF"
    """# Gabon """  # noqa: E501
    GA = "GA"
    """# Gambia """  # noqa: E501
    GM = "GM"
    """# Georgia """  # noqa: E501
    GE = "GE"
    """# Germany """  # noqa: E501
    DE = "DE"
    """# Ghana """  # noqa: E501
    GH = "GH"
    """# Gibraltar """  # noqa: E501
    GI = "GI"
    """# Greece """  # noqa: E501
    GR = "GR"
    """# Greenland """  # noqa: E501
    GL = "GL"
    """# Grenada """  # noqa: E501
    GD = "GD"
    """# Guadeloupe """  # noqa: E501
    GP = "GP"
    """# Guam """  # noqa: E501
    GU = "GU"
    """# Guatemala """  # noqa: E501
    GT = "GT"
    """# Guernsey """  # noqa: E501
    GG = "GG"
    """# Guinea """  # noqa: E501
    GN = "GN"
    """# Guinea-Bissau """  # noqa: E501
    GW = "GW"
    """# Guyana """  # noqa: E501
    GY = "GY"
    """# Haiti """  # noqa: E501
    HT = "HT"
    """# Heard Island and McDonald Islands """  # noqa: E501
    HM = "HM"
    """# Holy See """  # noqa: E501
    VA = "VA"
    """# Honduras """  # noqa: E501
    HN = "HN"
    """# Hong Kong """  # noqa: E501
    HK = "HK"
    """# Hungary """  # noqa: E501
    HU = "HU"
    """# Iceland """  # noqa: E501
    IS = "IS"
    """# India """  # noqa: E501
    IN = "IN"
    """# Indonesia """  # noqa: E501
    ID = "ID"
    """# Iran (Islamic Republic of) """  # noqa: E501
    IR = "IR"
    """# Iraq """  # noqa: E501
    IQ = "IQ"
    """# Ireland """  # noqa: E501
    IE = "IE"
    """# Isle of Man """  # noqa: E501
    IM = "IM"
    """# Israel """  # noqa: E501
    IL = "IL"
    """# Italy """  # noqa: E501
    IT = "IT"
    """# Jamaica """  # noqa: E501
    JM = "JM"
    """# Japan """  # noqa: E501
    JP = "JP"
    """# Jersey """  # noqa: E501
    JE = "JE"
    """# Jordan """  # noqa: E501
    JO = "JO"
    """# Kazakhstan """  # noqa: E501
    KZ = "KZ"
    """# Kenya """  # noqa: E501
    KE = "KE"
    """# Kiribati """  # noqa: E501
    KI = "KI"
    """# Korea (Democratic People's Republic of) """  # noqa: E501
    KP = "KP"
    """# Korea (Republic of) """  # noqa: E501
    KR = "KR"
    """# Kuwait """  # noqa: E501
    KW = "KW"
    """# Kyrgyzstan """  # noqa: E501
    KG = "KG"
    """# Lao People's Democratic Republic """  # noqa: E501
    LA = "LA"
    """# Latvia """  # noqa: E501
    LV = "LV"
    """# Lebanon """  # noqa: E501
    LB = "LB"
    """# Lesotho """  # noqa: E501
    LS = "LS"
    """# Liberia """  # noqa: E501
    LR = "LR"
    """# Libya """  # noqa: E501
    LY = "LY"
    """# Liechtenstein """  # noqa: E501
    LI = "LI"
    """# Lithuania """  # noqa: E501
    LT = "LT"
    """# Luxembourg """  # noqa: E501
    LU = "LU"
    """# Macao """  # noqa: E501
    MO = "MO"
    """# Macedonia (the former Yugoslav Republic of) """  # noqa: E501
    MK = "MK"
    """# Madagascar """  # noqa: E501
    MG = "MG"
    """# Malawi """  # noqa: E501
    MW = "MW"
    """# Malaysia """  # noqa: E501
    MY = "MY"
    """# Maldives """  # noqa: E501
    MV = "MV"
    """# Mali """  # noqa: E501
    ML = "ML"
    """# Malta """  # noqa: E501
    MT = "MT"
    """# Marshall Islands """  # noqa: E501
    MH = "MH"
    """# Martinique """  # noqa: E501
    MQ = "MQ"
    """# Mauritania """  # noqa: E501
    MR = "MR"
    """# Mauritius """  # noqa: E501
    MU = "MU"
    """# Mayotte """  # noqa: E501
    YT = "YT"
    """# Mexico """  # noqa: E501
    MX = "MX"
    """# Micronesia (Federated States of) """  # noqa: E501
    FM = "FM"
    """# Moldova (Republic of) """  # noqa: E501
    MD = "MD"
    """# Monaco """  # noqa: E501
    MC = "MC"
    """# Mongolia """  # noqa: E501
    MN = "MN"
    """# Montenegro """  # noqa: E501
    ME = "ME"
    """# Montserrat """  # noqa: E501
    MS = "MS"
    """# Morocco """  # noqa: E501
    MA = "MA"
    """# Mozambique """  # noqa: E501
    MZ = "MZ"
    """# Myanmar """  # noqa: E501
    MM = "MM"
    """# Namibia """  # noqa: E501
    NA = "NA"
    """# Nauru """  # noqa: E501
    NR = "NR"
    """# Nepal """  # noqa: E501
    NP = "NP"
    """# Netherlands """  # noqa: E501
    NL = "NL"
    """# New Caledonia """  # noqa: E501
    NC = "NC"
    """# New Zealand """  # noqa: E501
    NZ = "NZ"
    """# Nicaragua """  # noqa: E501
    NI = "NI"
    """# Niger """  # noqa: E501
    NE = "NE"
    """# Nigeria """  # noqa: E501
    NG = "NG"
    """# Niue """  # noqa: E501
    NU = "NU"
    """# Norfolk Island """  # noqa: E501
    NF = "NF"
    """# Northern Mariana Islands """  # noqa: E501
    MP = "MP"
    """# Norway """  # noqa: E501
    NO = "NO"
    """# Oman """  # noqa: E501
    OM = "OM"
    """# Pakistan """  # noqa: E501
    PK = "PK"
    """# Palau """  # noqa: E501
    PW = "PW"
    """# Palestine, State of """  # noqa: E501
    PS = "PS"
    """# Panama """  # noqa: E501
    PA = "PA"
    """# Papua New Guinea """  # noqa: E501
    PG = "PG"
    """# Paraguay """  # noqa: E501
    PY = "PY"
    """# Peru """  # noqa: E501
    PE = "PE"
    """# Philippines """  # noqa: E501
    PH = "PH"
    """# Pitcairn """  # noqa: E501
    PN = "PN"
    """# Poland """  # noqa: E501
    PL = "PL"
    """# Portugal """  # noqa: E501
    PT = "PT"
    """# Puerto Rico """  # noqa: E501
    PR = "PR"
    """# Qatar """  # noqa: E501
    QA = "QA"
    """# Réunion """  # noqa: E501
    RE = "RE"
    """# Romania """  # noqa: E501
    RO = "RO"
    """# Russian Federation """  # noqa: E501
    RU = "RU"
    """# Rwanda """  # noqa: E501
    RW = "RW"
    """# Saint Barthélemy """  # noqa: E501
    BL = "BL"
    """# Saint Helena, Ascension and Tristan da Cunha """  # noqa: E501
    SH = "SH"
    """# Saint Kitts and Nevis """  # noqa: E501
    KN = "KN"
    """# Saint Lucia """  # noqa: E501
    LC = "LC"
    """# Saint Martin (French part) """  # noqa: E501
    MF = "MF"
    """# Saint Pierre and Miquelon """  # noqa: E501
    PM = "PM"
    """# Saint Vincent and the Grenadines """  # noqa: E501
    VC = "VC"
    """# Samoa """  # noqa: E501
    WS = "WS"
    """# San Marino """  # noqa: E501
    SM = "SM"
    """# Sao Tome and Principe """  # noqa: E501
    ST = "ST"
    """# Saudi Arabia """  # noqa: E501
    SA = "SA"
    """# Senegal """  # noqa: E501
    SN = "SN"
    """# Serbia """  # noqa: E501
    RS = "RS"
    """# Seychelles """  # noqa: E501
    SC = "SC"
    """# Sierra Leone """  # noqa: E501
    SL = "SL"
    """# Singapore """  # noqa: E501
    SG = "SG"
    """# Sint Maarten (Dutch part) """  # noqa: E501
    SX = "SX"
    """# Slovakia """  # noqa: E501
    SK = "SK"
    """# Slovenia """  # noqa: E501
    SI = "SI"
    """# Solomon Islands """  # noqa: E501
    SB = "SB"
    """# Somalia """  # noqa: E501
    SO = "SO"
    """# South Africa """  # noqa: E501
    ZA = "ZA"
    """# South Georgia and the South Sandwich Islands """  # noqa: E501
    GS = "GS"
    """# South Sudan """  # noqa: E501
    SS = "SS"
    """# Spain """  # noqa: E501
    ES = "ES"
    """# Sri Lanka """  # noqa: E501
    LK = "LK"
    """# Sudan """  # noqa: E501
    SD = "SD"
    """# Suriname """  # noqa: E501
    SR = "SR"
    """# Svalbard and Jan Mayen """  # noqa: E501
    SJ = "SJ"
    """# Swaziland """  # noqa: E501
    SZ = "SZ"
    """# Sweden """  # noqa: E501
    SE = "SE"
    """# Switzerland """  # noqa: E501
    CH = "CH"
    """# Syrian Arab Republic """  # noqa: E501
    SY = "SY"
    """# Taiwan, Province of China """  # noqa: E501
    TW = "TW"
    """# Tajikistan """  # noqa: E501
    TJ = "TJ"
    """# Tanzania, United Republic of """  # noqa: E501
    TZ = "TZ"
    """# Thailand """  # noqa: E501
    TH = "TH"
    """# Timor-Leste """  # noqa: E501
    TL = "TL"
    """# Togo """  # noqa: E501
    TG = "TG"
    """# Tokelau """  # noqa: E501
    TK = "TK"
    """# Tonga """  # noqa: E501
    TO = "TO"
    """# Trinidad and Tobago """  # noqa: E501
    TT = "TT"
    """# Tunisia """  # noqa: E501
    TN = "TN"
    """# Turkey """  # noqa: E501
    TR = "TR"
    """# Turkmenistan """  # noqa: E501
    TM = "TM"
    """# Turks and Caicos Islands """  # noqa: E501
    TC = "TC"
    """# Tuvalu """  # noqa: E501
    TV = "TV"
    """# Uganda """  # noqa: E501
    UG = "UG"
    """# Ukraine """  # noqa: E501
    UA = "UA"
    """# United Arab Emirates """  # noqa: E501
    AE = "AE"
    """# United Kingdom of Great Britain and Northern Ireland """  # noqa: E501
    GB = "GB"
    """# United States of America """  # noqa: E501
    US = "US"
    """# United States Minor Outlying Islands """  # noqa: E501
    UM = "UM"
    """# Uruguay """  # noqa: E501
    UY = "UY"
    """# Uzbekistan """  # noqa: E501
    UZ = "UZ"
    """# Vanuatu """  # noqa: E501
    VU = "VU"
    """# Venezuela (Bolivarian Republic of) """  # noqa: E501
    VE = "VE"
    """# Viet Nam """  # noqa: E501
    VN = "VN"
    """# Virgin Islands (British) """  # noqa: E501
    VG = "VG"
    """# Virgin Islands (U.S.) """  # noqa: E501
    VI = "VI"
    """# Wallis and Futuna """  # noqa: E501
    WF = "WF"
    """# Western Sahara """  # noqa: E501
    EH = "EH"
    """# Yemen """  # noqa: E501
    YE = "YE"
    """# Zambia """  # noqa: E501
    ZM = "ZM"
    """# Zimbabwe """  # noqa: E501
    ZW = "ZW"

    def __str__(self) -> str:
        return str(self.value)
